@@ -48,8 +48,6 @@ enum
 
 
 
-static void tvm_command_entry_class_init    (TvmCommandEntryClass *klass);
-static void tvm_command_entry_init          (TvmCommandEntry      *command_entry);
 static void tvm_command_entry_finalize      (GObject              *object);
 static void tvm_command_entry_get_property  (GObject              *object,
                                              guint                 prop_id,
@@ -64,36 +62,7 @@ static void tvm_command_entry_clicked       (GtkWidget            *button,
 
 
 
-static GObjectClass *tvm_command_entry_parent_class;
-
-
-
-GType
-tvm_command_entry_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      static const GTypeInfo info =
-      {
-        sizeof (TvmCommandEntryClass),
-        NULL,
-        NULL,
-        (GClassInitFunc) tvm_command_entry_class_init,
-        NULL,
-        NULL,
-        sizeof (TvmCommandEntry),
-        0,
-        (GInstanceInitFunc) tvm_command_entry_init,
-        NULL,
-      };
-
-      type = g_type_register_static (GTK_TYPE_BOX, I_("TvmCommandEntry"), &info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (TvmCommandEntry, tvm_command_entry, GTK_TYPE_BOX)
 
 
 
@@ -102,9 +71,6 @@ tvm_command_entry_class_init (TvmCommandEntryClass *klass)
 {
   GObjectClass *gobject_class;
 
-  /* determine the parent type class */
-  tvm_command_entry_parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = tvm_command_entry_finalize;
   gobject_class->get_property = tvm_command_entry_get_property;
@@ -142,7 +108,7 @@ tvm_command_entry_init (TvmCommandEntry *command_entry)
 
   command_entry->entry = gtk_entry_new ();
   gtk_label_set_mnemonic_widget (GTK_LABEL (command_entry->label), command_entry->entry);
-  exo_mutual_binding_new (G_OBJECT (command_entry->entry), "text", G_OBJECT (command_entry), "command");
+  g_object_bind_property (G_OBJECT (command_entry->entry), "text", G_OBJECT (command_entry), "command", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
   gtk_box_pack_start (GTK_BOX (command_entry), command_entry->entry, TRUE, TRUE, 0);
   gtk_widget_show (command_entry->entry);
 
